Struct NodeMath

struct NodeMath { ... }

An inline math span

Fields

dollar_math: bool

Whether this is dollar math ($ or $$). false indicates it is code math

display_math: bool

Whether this is display math (using $$)

literal: String

The literal contents of the math span.
As the contents are not interpreted as Markdown at all, they are contained within this structure, rather than inserted into a child inline of any kind.

Implementations

impl Clone for NodeMath

fn clone(self: &Self) -> NodeMath

impl Debug for NodeMath

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for NodeMath

impl Freeze for NodeMath

impl PartialEq for NodeMath

fn eq(self: &Self, other: &NodeMath) -> bool

impl RefUnwindSafe for NodeMath

impl Send for NodeMath

impl StructuralPartialEq for NodeMath

impl Sync for NodeMath

impl Unpin for NodeMath

impl UnsafeUnpin for NodeMath

impl UnwindSafe for NodeMath

impl<T> Any for NodeMath

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for NodeMath

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for NodeMath

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for NodeMath

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for NodeMath

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for NodeMath

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for NodeMath

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for NodeMath

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for NodeMath

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>