Struct ParseOptions
struct ParseOptions<'c> { ... }
Options for parser functions.
Fields
smart: boolPunctuation (quotes, full-stops and hyphens) are converted into 'smart' punctuation.
# use ; let mut options = default; assert_eq!; options.parse.smart = true; assert_eq!;default_info_string: Option<String>The default info string for fenced code blocks.
# use ; let mut options = default; assert_eq!; options.parse.default_info_string = Some; assert_eq!;relaxed_tasklist_matching: boolWhether or not a simple
xorXis used for tasklist or any other symbol is allowed.relaxed_autolinks: boolRelax parsing of autolinks, allow links to be detected inside brackets and allow all url schemes. It is intended to allow a very specific type of autolink detection, such as
[this http://and.com that]or{http://foo.com}, on a best can basis.# use ; let mut options = default; options.extension.autolink = true; assert_eq!; options.parse.relaxed_autolinks = true; assert_eq!;broken_link_callback: Option<Arc<dyn BrokenLinkCallback + 'c>>In case the parser encounters any potential links that have a broken reference (e.g
[foo]when there is no[foo]: urlentry at the bottom) the provided callback will be called with the reference name, both in normalized form and unmodified, and the returned pair will be used as the link destination and title if notNone.# use ; # use ; let cb = ; let mut options = default; options.parse.broken_link_callback = Some; let output = markdown_to_html; assert_eq!;
Implementations
impl<'c> Clone for ParseOptions<'c>
fn clone(self: &Self) -> ParseOptions<'c>
impl<'c> Debug for ParseOptions<'c>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'c> Default for ParseOptions<'c>
fn default() -> ParseOptions<'c>
impl<'c> Freeze for ParseOptions<'c>
impl<'c> RefUnwindSafe for ParseOptions<'c>
impl<'c> Send for ParseOptions<'c>
impl<'c> Sync for ParseOptions<'c>
impl<'c> Unpin for ParseOptions<'c>
impl<'c> UnsafeUnpin for ParseOptions<'c>
impl<'c> UnwindSafe for ParseOptions<'c>
impl<T> Any for ParseOptions<'c>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ParseOptions<'c>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ParseOptions<'c>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ParseOptions<'c>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ParseOptions<'c>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ParseOptions<'c>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ParseOptions<'c>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ParseOptions<'c>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ParseOptions<'c>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>